# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/internal/v1/authorize.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%aruna/api/internal/v1/authorize.proto\x12\x15\x61runa.api.internal.v1\x1a\x1bgoogle/api/visibility.proto\x1a(aruna/api/storage/models/v1/models.proto\"K\n\rAuthorization\x12\x1c\n\tsecretkey\x18\x01 \x01(\tR\tsecretkey\x12\x1c\n\taccesskey\x18\x02 \x01(\tR\taccesskey\"W\n\nIdentifier\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x35\n\x06idtype\x18\x02 \x01(\x0e\x32\x1d.aruna.api.internal.v1.IdTypeR\x06idtype\"\xbe\x02\n\x10\x41uthorizeRequest\x12\x45\n\x08resource\x18\x01 \x01(\x0e\x32).aruna.api.storage.models.v1.ResourceTypeR\x08resource\x12\x41\n\nidentifier\x18\x02 \x01(\x0b\x32!.aruna.api.internal.v1.IdentifierR\nidentifier\x12T\n\x0fresource_action\x18\x03 \x01(\x0e\x32+.aruna.api.storage.models.v1.ResourceActionR\x0eresourceAction\x12J\n\rauthorization\x18\x04 \x01(\x0b\x32$.aruna.api.internal.v1.AuthorizationR\rauthorization\"#\n\x11\x41uthorizeResponse\x12\x0e\n\x02ok\x18\x01 \x01(\x08R\x02ok\"0\n\x10GetSecretRequest\x12\x1c\n\taccesskey\x18\x01 \x01(\tR\taccesskey\"_\n\x11GetSecretResponse\x12J\n\rauthorization\x18\x01 \x01(\x0b\x32$.aruna.api.internal.v1.AuthorizationR\rauthorization*E\n\x06IdType\x12\x17\n\x13ID_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cID_TYPE_UUID\x10\x01\x12\x10\n\x0cID_TYPE_PATH\x10\x02\x32\xf0\x01\n\x18InternalAuthorizeService\x12`\n\tAuthorize\x12\'.aruna.api.internal.v1.AuthorizeRequest\x1a(.aruna.api.internal.v1.AuthorizeResponse\"\x00\x12`\n\tGetSecret\x12\'.aruna.api.internal.v1.GetSecretRequest\x1a(.aruna.api.internal.v1.GetSecretResponse\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB6Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.internal.v1.authorize_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1'
  _INTERNALAUTHORIZESERVICE._options = None
  _INTERNALAUTHORIZESERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _IDTYPE._serialized_start=806
  _IDTYPE._serialized_end=875
  _AUTHORIZATION._serialized_start=135
  _AUTHORIZATION._serialized_end=210
  _IDENTIFIER._serialized_start=212
  _IDENTIFIER._serialized_end=299
  _AUTHORIZEREQUEST._serialized_start=302
  _AUTHORIZEREQUEST._serialized_end=620
  _AUTHORIZERESPONSE._serialized_start=622
  _AUTHORIZERESPONSE._serialized_end=657
  _GETSECRETREQUEST._serialized_start=659
  _GETSECRETREQUEST._serialized_end=707
  _GETSECRETRESPONSE._serialized_start=709
  _GETSECRETRESPONSE._serialized_end=804
  _INTERNALAUTHORIZESERVICE._serialized_start=878
  _INTERNALAUTHORIZESERVICE._serialized_end=1118
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/models/v1/models.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(aruna/api/storage/models/v1/models.proto\x12\x1b\x61runa.api.storage.models.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"2\n\x08KeyValue\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"?\n\rLabelOntology\x12.\n\x13required_label_keys\x18\x01 \x03(\tR\x11requiredLabelKeys\"8\n\x05Stats\x12\x14\n\x05\x63ount\x18\x01 \x01(\x03R\x05\x63ount\x12\x19\n\x08\x61\x63\x63_size\x18\x02 \x01(\x03R\x07\x61\x63\x63Size\"\xc5\x01\n\x0f\x43ollectionStats\x12\x45\n\x0cobject_stats\x18\x01 \x01(\x0b\x32\".aruna.api.storage.models.v1.StatsR\x0bobjectStats\x12,\n\x12object_group_count\x18\x02 \x01(\x03R\x10objectGroupCount\x12=\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0blastUpdated\"\x98\x01\n\x10ObjectGroupStats\x12\x45\n\x0cobject_stats\x18\x01 \x01(\x0b\x32\".aruna.api.storage.models.v1.StatsR\x0bobjectStats\x12=\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0blastUpdated\"K\n\x07Version\x12\x14\n\x05major\x18\x01 \x01(\x05R\x05major\x12\x14\n\x05minor\x18\x02 \x01(\x05R\x05minor\x12\x14\n\x05patch\x18\x03 \x01(\x05R\x05patch\"X\n\x04Hash\x12<\n\x03\x61lg\x18\x01 \x01(\x0e\x32*.aruna.api.storage.models.v1.HashalgorithmR\x03\x61lg\x12\x12\n\x04hash\x18\x02 \x01(\tR\x04hash\"\x1e\n\x06Origin\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02idJ\x04\x08\x01\x10\x02\"r\n\x06Source\x12\x1e\n\nidentifier\x18\x01 \x01(\tR\nidentifier\x12H\n\x0bsource_type\x18\x02 \x01(\x0e\x32\'.aruna.api.storage.models.v1.SourceTypeR\nsourceType\"\xf6\x02\n\x08\x45ndpoint\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x42\n\x07\x65p_type\x18\x02 \x01(\x0e\x32).aruna.api.storage.models.v1.EndpointTypeR\x06\x65pType\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12%\n\x0eproxy_hostname\x18\x04 \x01(\tR\rproxyHostname\x12+\n\x11internal_hostname\x18\x05 \x01(\tR\x10internalHostname\x12-\n\x12\x64ocumentation_path\x18\x06 \x01(\tR\x11\x64ocumentationPath\x12\x1b\n\tis_public\x18\x07 \x01(\x08R\x08isPublic\x12\x1d\n\nis_default\x18\x08 \x01(\x08R\tisDefault\x12\x43\n\x06status\x18\t \x01(\x0e\x32+.aruna.api.storage.models.v1.EndpointStatusR\x06status\"\x9e\x05\n\x06Object\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1a\n\x08\x66ilename\x18\x02 \x01(\tR\x08\x66ilename\x12=\n\x06labels\x18\x04 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x05 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12\x34\n\x07\x63reated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x63reated\x12\x1f\n\x0b\x63ontent_len\x18\x07 \x01(\x03R\ncontentLen\x12;\n\x06status\x18\x08 \x01(\x0e\x32#.aruna.api.storage.models.v1.StatusR\x06status\x12;\n\x06origin\x18\t \x01(\x0b\x32#.aruna.api.storage.models.v1.OriginR\x06origin\x12\x45\n\ndata_class\x18\n \x01(\x0e\x32&.aruna.api.storage.models.v1.DataClassR\tdataClass\x12\x39\n\x06hashes\x18\x10 \x03(\x0b\x32!.aruna.api.storage.models.v1.HashR\x06hashes\x12\x1d\n\nrev_number\x18\x0c \x01(\x03R\trevNumber\x12;\n\x06source\x18\r \x01(\x0b\x32#.aruna.api.storage.models.v1.SourceR\x06source\x12\x16\n\x06latest\x18\x0e \x01(\x08R\x06latest\x12\x1f\n\x0b\x61uto_update\x18\x0f \x01(\x08R\nautoUpdateJ\x04\x08\x0b\x10\x0c\"H\n\x07Objects\x12=\n\x07objects\x18\x01 \x03(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x07objects\"\xba\x03\n\x0bObjectGroup\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12=\n\x06labels\x18\x06 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x07 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12=\n\x07objects\x18\x08 \x03(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x07objects\x12\x46\n\x0cmeta_objects\x18\t \x03(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x0bmetaObjects\x12\x43\n\x05stats\x18\n \x01(\x0b\x32-.aruna.api.storage.models.v1.ObjectGroupStatsR\x05stats\x12\x1d\n\nrev_number\x18\x0b \x01(\x03R\trevNumber\"]\n\x0cObjectGroups\x12M\n\robject_groups\x18\x01 \x03(\x0b\x32(.aruna.api.storage.models.v1.ObjectGroupR\x0cobjectGroups\"\xbb\x02\n\x13ObjectGroupOverview\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12=\n\x06labels\x18\x06 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x07 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12\x43\n\x05stats\x18\x08 \x01(\x0b\x32-.aruna.api.storage.models.v1.ObjectGroupStatsR\x05stats\x12\x1d\n\nrev_number\x18\t \x01(\x03R\trevNumber\"~\n\x14ObjectGroupOverviews\x12\x66\n\x16object_group_overviews\x18\x01 \x03(\x0b\x32\x30.aruna.api.storage.models.v1.ObjectGroupOverviewR\x14objectGroupOverviews\"\x80\x03\n\x11ObjectGroupWithID\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12=\n\x06labels\x18\x06 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x07 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12\x1d\n\nobject_ids\x18\x08 \x03(\tR\tobjectIds\x12&\n\x0fmeta_object_ids\x18\t \x03(\tR\rmetaObjectIds\x12\x43\n\x05stats\x18\n \x01(\x0b\x32-.aruna.api.storage.models.v1.ObjectGroupStatsR\x05stats\x12\x1d\n\nrev_number\x18\x0b \x01(\x03R\trevNumber\"w\n\x12ObjectGroupWithIDs\x12\x61\n\x15object_group_with_ids\x18\x01 \x03(\x0b\x32..aruna.api.storage.models.v1.ObjectGroupWithIDR\x12objectGroupWithIds\"\x8b\x06\n\nCollection\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12=\n\x06labels\x18\x04 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x05 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12Q\n\x0elabel_ontology\x18\x06 \x01(\x0b\x32*.aruna.api.storage.models.v1.LabelOntologyR\rlabelOntology\x12\x34\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x63reated\x12=\n\x07objects\x18\x08 \x03(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x07objects\x12K\n\x0especifications\x18\t \x03(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x0especifications\x12M\n\robject_groups\x18\n \x03(\x0b\x32(.aruna.api.storage.models.v1.ObjectGroupR\x0cobjectGroups\x12Q\n\x10semantic_version\x18\x0c \x01(\x0b\x32$.aruna.api.storage.models.v1.VersionH\x00R\x0fsemanticVersion\x12\x18\n\x06latest\x18\r \x01(\x08H\x00R\x06latest\x12\x42\n\x05stats\x18\x0e \x01(\x0b\x32,.aruna.api.storage.models.v1.CollectionStatsR\x05stats\x12\x1b\n\tis_public\x18\x0f \x01(\x08R\x08isPublicB\t\n\x07version\"X\n\x0b\x43ollections\x12I\n\x0b\x63ollections\x18\x01 \x03(\x0b\x32\'.aruna.api.storage.models.v1.CollectionR\x0b\x63ollections\"\xb8\x04\n\x12\x43ollectionOverview\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12=\n\x06labels\x18\x04 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x05 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12Q\n\x0elabel_ontology\x18\x06 \x01(\x0b\x32*.aruna.api.storage.models.v1.LabelOntologyR\rlabelOntology\x12\x34\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x63reated\x12Q\n\x10semantic_version\x18\x0c \x01(\x0b\x32$.aruna.api.storage.models.v1.VersionH\x00R\x0fsemanticVersion\x12\x18\n\x06latest\x18\r \x01(\x08H\x00R\x06latest\x12\x42\n\x05stats\x18\x0e \x01(\x0b\x32,.aruna.api.storage.models.v1.CollectionStatsR\x05stats\x12\x1b\n\tis_public\x18\x0f \x01(\x08R\x08isPublicB\t\n\x07version\"y\n\x13\x43ollectionOverviews\x12\x62\n\x14\x63ollection_overviews\x18\x01 \x03(\x0b\x32/.aruna.api.storage.models.v1.CollectionOverviewR\x13\x63ollectionOverviews\"\x9d\x05\n\x10\x43ollectionWithID\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12=\n\x06labels\x18\x04 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x05 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12Q\n\x0elabel_ontology\x18\x06 \x01(\x0b\x32*.aruna.api.storage.models.v1.LabelOntologyR\rlabelOntology\x12\x34\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x63reated\x12\x18\n\x07objects\x18\x08 \x03(\tR\x07objects\x12&\n\x0especifications\x18\t \x03(\tR\x0especifications\x12#\n\robject_groups\x18\n \x03(\tR\x0cobjectGroups\x12Q\n\x10semantic_version\x18\x0c \x01(\x0b\x32$.aruna.api.storage.models.v1.VersionH\x00R\x0fsemanticVersion\x12\x18\n\x06latest\x18\r \x01(\x08H\x00R\x06latest\x12\x42\n\x05stats\x18\x0e \x01(\x0b\x32,.aruna.api.storage.models.v1.CollectionStatsR\x05stats\x12\x1b\n\tis_public\x18\x0f \x01(\x08R\x08isPublicB\t\n\x07version\"r\n\x11\x43ollectionWithIDs\x12]\n\x13\x63ollection_with_ids\x18\x01 \x03(\x0b\x32-.aruna.api.storage.models.v1.CollectionWithIDR\x11\x63ollectionWithIds*\xb7\x01\n\x0cResourceType\x12\x1d\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15RESOURCE_TYPE_PROJECT\x10\x01\x12\x1c\n\x18RESOURCE_TYPE_COLLECTION\x10\x02\x12\x1e\n\x1aRESOURCE_TYPE_OBJECT_GROUP\x10\x03\x12\x18\n\x14RESOURCE_TYPE_OBJECT\x10\x04\x12\x15\n\x11RESOURCE_TYPE_ALL\x10\x05*\xbb\x01\n\x0eResourceAction\x12\x1f\n\x1bRESOURCE_ACTION_UNSPECIFIED\x10\x00\x12\x1a\n\x16RESOURCE_ACTION_CREATE\x10\x01\x12\x1a\n\x16RESOURCE_ACTION_APPEND\x10\x02\x12\x1a\n\x16RESOURCE_ACTION_UPDATE\x10\x03\x12\x18\n\x14RESOURCE_ACTION_READ\x10\x04\x12\x1a\n\x16RESOURCE_ACTION_DELETE\x10\x05*\xa2\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13STATUS_INITIALIZING\x10\x01\x12\x14\n\x10STATUS_AVAILABLE\x10\x02\x12\x16\n\x12STATUS_UNAVAILABLE\x10\x03\x12\x10\n\x0cSTATUS_ERROR\x10\x04\x12\x10\n\x0cSTATUS_TRASH\x10\x05\x12\x15\n\x11STATUS_FINALIZING\x10\x06*\xd2\x01\n\x0e\x45ndpointStatus\x12\x1f\n\x1b\x45NDPOINT_STATUS_UNSPECIFIED\x10\x00\x12 \n\x1c\x45NDPOINT_STATUS_INITIALIZING\x10\x01\x12\x1d\n\x19\x45NDPOINT_STATUS_AVAILABLE\x10\x02\x12\x1c\n\x18\x45NDPOINT_STATUS_DEGRADED\x10\x03\x12\x1f\n\x1b\x45NDPOINT_STATUS_UNAVAILABLE\x10\x04\x12\x1f\n\x1b\x45NDPOINT_STATUS_MAINTENANCE\x10\x05*k\n\rHashalgorithm\x12\x1d\n\x19HASHALGORITHM_UNSPECIFIED\x10\x00\x12\x15\n\x11HASHALGORITHM_MD5\x10\x01\x12\x18\n\x14HASHALGORITHM_SHA256\x10\x03\"\x04\x08\x02\x10\x02\"\x04\x08\x04\x10\x07*\x8d\x01\n\tDataClass\x12\x1a\n\x16\x44\x41TA_CLASS_UNSPECIFIED\x10\x00\x12\x15\n\x11\x44\x41TA_CLASS_PUBLIC\x10\x01\x12\x16\n\x12\x44\x41TA_CLASS_PRIVATE\x10\x02\x12\x1b\n\x17\x44\x41TA_CLASS_CONFIDENTIAL\x10\x03\x12\x18\n\x14\x44\x41TA_CLASS_PROTECTED\x10\x04*S\n\nSourceType\x12\x1b\n\x17SOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSOURCE_TYPE_URL\x10\x01\x12\x13\n\x0fSOURCE_TYPE_DOI\x10\x02*[\n\x0c\x45ndpointType\x12\x1d\n\x19\x45NDPOINT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45NDPOINT_TYPE_S3\x10\x01\x12\x16\n\x12\x45NDPOINT_TYPE_FILE\x10\x02\x42<Z:github.com/ArunaStorage/go-api/aruna/api/storage/models/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.models.v1.models_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/ArunaStorage/go-api/aruna/api/storage/models/v1'
  _RESOURCETYPE._serialized_start=5924
  _RESOURCETYPE._serialized_end=6107
  _RESOURCEACTION._serialized_start=6110
  _RESOURCEACTION._serialized_end=6297
  _STATUS._serialized_start=6300
  _STATUS._serialized_end=6462
  _ENDPOINTSTATUS._serialized_start=6465
  _ENDPOINTSTATUS._serialized_end=6675
  _HASHALGORITHM._serialized_start=6677
  _HASHALGORITHM._serialized_end=6784
  _DATACLASS._serialized_start=6787
  _DATACLASS._serialized_end=6928
  _SOURCETYPE._serialized_start=6930
  _SOURCETYPE._serialized_end=7013
  _ENDPOINTTYPE._serialized_start=7015
  _ENDPOINTTYPE._serialized_end=7106
  _KEYVALUE._serialized_start=106
  _KEYVALUE._serialized_end=156
  _LABELONTOLOGY._serialized_start=158
  _LABELONTOLOGY._serialized_end=221
  _STATS._serialized_start=223
  _STATS._serialized_end=279
  _COLLECTIONSTATS._serialized_start=282
  _COLLECTIONSTATS._serialized_end=479
  _OBJECTGROUPSTATS._serialized_start=482
  _OBJECTGROUPSTATS._serialized_end=634
  _VERSION._serialized_start=636
  _VERSION._serialized_end=711
  _HASH._serialized_start=713
  _HASH._serialized_end=801
  _ORIGIN._serialized_start=803
  _ORIGIN._serialized_end=833
  _SOURCE._serialized_start=835
  _SOURCE._serialized_end=949
  _ENDPOINT._serialized_start=952
  _ENDPOINT._serialized_end=1326
  _OBJECT._serialized_start=1329
  _OBJECT._serialized_end=1999
  _OBJECTS._serialized_start=2001
  _OBJECTS._serialized_end=2073
  _OBJECTGROUP._serialized_start=2076
  _OBJECTGROUP._serialized_end=2518
  _OBJECTGROUPS._serialized_start=2520
  _OBJECTGROUPS._serialized_end=2613
  _OBJECTGROUPOVERVIEW._serialized_start=2616
  _OBJECTGROUPOVERVIEW._serialized_end=2931
  _OBJECTGROUPOVERVIEWS._serialized_start=2933
  _OBJECTGROUPOVERVIEWS._serialized_end=3059
  _OBJECTGROUPWITHID._serialized_start=3062
  _OBJECTGROUPWITHID._serialized_end=3446
  _OBJECTGROUPWITHIDS._serialized_start=3448
  _OBJECTGROUPWITHIDS._serialized_end=3567
  _COLLECTION._serialized_start=3570
  _COLLECTION._serialized_end=4349
  _COLLECTIONS._serialized_start=4351
  _COLLECTIONS._serialized_end=4439
  _COLLECTIONOVERVIEW._serialized_start=4442
  _COLLECTIONOVERVIEW._serialized_end=5010
  _COLLECTIONOVERVIEWS._serialized_start=5012
  _COLLECTIONOVERVIEWS._serialized_end=5133
  _COLLECTIONWITHID._serialized_start=5136
  _COLLECTIONWITHID._serialized_end=5805
  _COLLECTIONWITHIDS._serialized_start=5807
  _COLLECTIONWITHIDS._serialized_end=5921
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.storage.services.v1 import user_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2


class UserServiceStub(object):
    """UserService

    Contains all methods that get/create or update Users and associated resource
    including all autorization methods
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterUser = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/RegisterUser',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserResponse.FromString,
                )
        self.DeactivateUser = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/DeactivateUser',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserResponse.FromString,
                )
        self.ActivateUser = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/ActivateUser',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserResponse.FromString,
                )
        self.CreateAPIToken = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/CreateAPIToken',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenResponse.FromString,
                )
        self.GetAPIToken = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetAPIToken',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenResponse.FromString,
                )
        self.GetAPITokens = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetAPITokens',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensResponse.FromString,
                )
        self.DeleteAPIToken = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/DeleteAPIToken',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenResponse.FromString,
                )
        self.DeleteAPITokens = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/DeleteAPITokens',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensResponse.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetUser',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserResponse.FromString,
                )
        self.UpdateUserDisplayName = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/UpdateUserDisplayName',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameResponse.FromString,
                )
        self.UpdateUserEmail = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/UpdateUserEmail',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailResponse.FromString,
                )
        self.GetUserProjects = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetUserProjects',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsResponse.FromString,
                )
        self.GetNotActivatedUsers = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetNotActivatedUsers',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersResponse.FromString,
                )
        self.GetAllUsers = channel.unary_unary(
                '/aruna.api.storage.services.v1.UserService/GetAllUsers',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersResponse.FromString,
                )


class UserServiceServicer(object):
    """UserService

    Contains all methods that get/create or update Users and associated resource
    including all autorization methods
    """

    def RegisterUser(self, request, context):
        """RegisterUser

        Status: STABLE

        This request should be called when a new user logs in for the first time
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeactivateUser(self, request, context):
        """DeActivateUser 

        Status: ALPHA

        This deactivates a specific user (Admin request)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateUser(self, request, context):
        """ActivateUser 

        Status: STABLE

        This activates a specific user (Admin request)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAPIToken(self, request, context):
        """CreateAPIToken

        Status: STABLE

        Creates an API token to authenticate
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAPIToken(self, request, context):
        """GetAPIToken

        Status: STABLE

        Returns one API token by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAPITokens(self, request, context):
        """GetAPITokens

        Status: STABLE

        Returns a list of API tokens for a specific user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAPIToken(self, request, context):
        """DeleteAPIToken

        Status: STABLE

        Deletes the specified API Token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAPITokens(self, request, context):
        """DeleteAPITokens

        Status: STABLE

        Deletes the specified API Token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """GetUserRequest

        Status: STABLE

        This is a request that returns the user information of the
        current user or if invoked by an admin from another user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserDisplayName(self, request, context):
        """UpdateUserDisplayName

        Status: STABLE

        Updates the Displayname for the user (Personal only)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserEmail(self, request, context):
        """UpdateUserDisplayName

        Status: ALPHA

        Updates the email for the user (Personal only)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserProjects(self, request, context):
        """GetUserProjects

        Status: STABLE

        Gets all project_ids a user is member of
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNotActivatedUsers(self, request, context):
        """GetNotActivatedUsers

        Status: STABLE

        Get all not activated users (Admin only)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllUsers(self, request, context):
        """GetAllUsers

        Status: ALPHA

        Get all users inkluding permissions (Admin only)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterUser': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterUser,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserResponse.SerializeToString,
            ),
            'DeactivateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeactivateUser,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserResponse.SerializeToString,
            ),
            'ActivateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateUser,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserResponse.SerializeToString,
            ),
            'CreateAPIToken': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAPIToken,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenResponse.SerializeToString,
            ),
            'GetAPIToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAPIToken,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenResponse.SerializeToString,
            ),
            'GetAPITokens': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAPITokens,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensResponse.SerializeToString,
            ),
            'DeleteAPIToken': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAPIToken,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenResponse.SerializeToString,
            ),
            'DeleteAPITokens': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAPITokens,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensResponse.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserResponse.SerializeToString,
            ),
            'UpdateUserDisplayName': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserDisplayName,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameResponse.SerializeToString,
            ),
            'UpdateUserEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserEmail,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailResponse.SerializeToString,
            ),
            'GetUserProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserProjects,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsResponse.SerializeToString,
            ),
            'GetNotActivatedUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotActivatedUsers,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersResponse.SerializeToString,
            ),
            'GetAllUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllUsers,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.storage.services.v1.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserService(object):
    """UserService

    Contains all methods that get/create or update Users and associated resource
    including all autorization methods
    """

    @staticmethod
    def RegisterUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/RegisterUser',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.RegisterUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeactivateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/DeactivateUser',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeactivateUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/ActivateUser',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.ActivateUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAPIToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/CreateAPIToken',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.CreateAPITokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAPIToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetAPIToken',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAPITokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetAPITokens',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAPITokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAPIToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/DeleteAPIToken',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAPITokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/DeleteAPITokens',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.DeleteAPITokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetUser',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserDisplayName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/UpdateUserDisplayName',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserDisplayNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/UpdateUserEmail',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.UpdateUserEmailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetUserProjects',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetUserProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNotActivatedUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetNotActivatedUsers',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetNotActivatedUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.UserService/GetAllUsers',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_user__service__pb2.GetAllUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.storage.services.v1 import project_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2


class ProjectServiceStub(object):
    """ProjectService

    Contains all methods that get/create or update Projects and associated resources
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateProject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ProjectService/CreateProject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.CreateProjectResponse.FromString,
                )
        self.AddUserToProject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ProjectService/AddUserToProject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.AddUserToProjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.AddUserToProjectResponse.FromString,
                )
        self.GetProject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ProjectService/GetProject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectResponse.FromString,
                )
        self.GetProjects = channel.unary_unary(
                '/aruna.api.storage.services.v1.ProjectService/GetProjects',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectsResponse.FromString,
                )
        self.DestroyProject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ProjectService/DestroyProject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.DestroyProjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.DestroyProjectResponse.FromString,
                )
        self.UpdateProject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ProjectService/UpdateProject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.UpdateProjectResponse.FromString,
                )
        self.RemoveUserFromProject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ProjectService/RemoveUserFromProject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.RemoveUserFromProjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.RemoveUserFromProjectResponse.FromString,
                )
        self.GetUserPermissionsForProject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ProjectService/GetUserPermissionsForProject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetUserPermissionsForProjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetUserPermissionsForProjectResponse.FromString,
                )
        self.GetAllUserPermissionsForProject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ProjectService/GetAllUserPermissionsForProject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetAllUserPermissionsForProjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetAllUserPermissionsForProjectResponse.FromString,
                )
        self.EditUserPermissionsForProject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ProjectService/EditUserPermissionsForProject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.EditUserPermissionsForProjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.EditUserPermissionsForProjectResponse.FromString,
                )


class ProjectServiceServicer(object):
    """ProjectService

    Contains all methods that get/create or update Projects and associated resources
    """

    def CreateProject(self, request, context):
        """CreateProject

        Status: STABLE

        Creates a new project all users and collections are bundled in a project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddUserToProject(self, request, context):
        """AddUserToProject

        Status: STABLE

        Adds a new user to a given project by its id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProject(self, request, context):
        """GetProject

        Status: STABLE

        Requests a project by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjects(self, request, context):
        """GetProjects

        Status: STABLE

        Admin request to get all projects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DestroyProject(self, request, context):
        """DestroyProject

        Status: STABLE

        Destroys the project and all its associated data. Must be empty
        (cannot contain any collections).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProject(self, request, context):
        """UpdateProject

        Status: STABLE

        Updates the project. All (meta) data will be overwritten.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveUserFromProject(self, request, context):
        """RemoveUserFromProject

        Status: STABLE

        Removes a specified user from the project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserPermissionsForProject(self, request, context):
        """GetUserPermissionsForProject

        Status: STABLE

        Get the user_permission of a specific user for the project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllUserPermissionsForProject(self, request, context):
        """GetAllUserPermissionsForProject

        Status: ALPHA

        Get the user_permission of a specific user for the project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditUserPermissionsForProject(self, request, context):
        """EditUserPermissionsForProject

        Status: STABLE

        Modifies the user_permission of a specific user for the project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateProject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.CreateProjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.CreateProjectResponse.SerializeToString,
            ),
            'AddUserToProject': grpc.unary_unary_rpc_method_handler(
                    servicer.AddUserToProject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.AddUserToProjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.AddUserToProjectResponse.SerializeToString,
            ),
            'GetProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectResponse.SerializeToString,
            ),
            'GetProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjects,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectsResponse.SerializeToString,
            ),
            'DestroyProject': grpc.unary_unary_rpc_method_handler(
                    servicer.DestroyProject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.DestroyProjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.DestroyProjectResponse.SerializeToString,
            ),
            'UpdateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.UpdateProjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.UpdateProjectResponse.SerializeToString,
            ),
            'RemoveUserFromProject': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveUserFromProject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.RemoveUserFromProjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.RemoveUserFromProjectResponse.SerializeToString,
            ),
            'GetUserPermissionsForProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserPermissionsForProject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetUserPermissionsForProjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetUserPermissionsForProjectResponse.SerializeToString,
            ),
            'GetAllUserPermissionsForProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllUserPermissionsForProject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetAllUserPermissionsForProjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetAllUserPermissionsForProjectResponse.SerializeToString,
            ),
            'EditUserPermissionsForProject': grpc.unary_unary_rpc_method_handler(
                    servicer.EditUserPermissionsForProject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.EditUserPermissionsForProjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.EditUserPermissionsForProjectResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.storage.services.v1.ProjectService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectService(object):
    """ProjectService

    Contains all methods that get/create or update Projects and associated resources
    """

    @staticmethod
    def CreateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ProjectService/CreateProject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.CreateProjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.CreateProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddUserToProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ProjectService/AddUserToProject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.AddUserToProjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.AddUserToProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ProjectService/GetProject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ProjectService/GetProjects',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DestroyProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ProjectService/DestroyProject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.DestroyProjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.DestroyProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ProjectService/UpdateProject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.UpdateProjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.UpdateProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveUserFromProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ProjectService/RemoveUserFromProject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.RemoveUserFromProjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.RemoveUserFromProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserPermissionsForProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ProjectService/GetUserPermissionsForProject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetUserPermissionsForProjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetUserPermissionsForProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllUserPermissionsForProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ProjectService/GetAllUserPermissionsForProject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetAllUserPermissionsForProjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.GetAllUserPermissionsForProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditUserPermissionsForProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ProjectService/EditUserPermissionsForProject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.EditUserPermissionsForProjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_project__service__pb2.EditUserPermissionsForProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from aruna.api.storage.models.v1 import auth_pb2 as _auth_pb2
from google.api import annotations_pb2 as _annotations_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddUserToProjectRequest(_message.Message):
    __slots__ = ["project_id", "user_permission"]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    user_permission: _auth_pb2.ProjectPermission
    def __init__(self, project_id: _Optional[str] = ..., user_permission: _Optional[_Union[_auth_pb2.ProjectPermission, _Mapping]] = ...) -> None: ...

class AddUserToProjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateProjectRequest(_message.Message):
    __slots__ = ["description", "name"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    description: str
    name: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class CreateProjectResponse(_message.Message):
    __slots__ = ["project_id"]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class DestroyProjectRequest(_message.Message):
    __slots__ = ["project_id"]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class DestroyProjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class EditUserPermissionsForProjectRequest(_message.Message):
    __slots__ = ["project_id", "user_permission"]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    user_permission: _auth_pb2.ProjectPermission
    def __init__(self, project_id: _Optional[str] = ..., user_permission: _Optional[_Union[_auth_pb2.ProjectPermission, _Mapping]] = ...) -> None: ...

class EditUserPermissionsForProjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetAllUserPermissionsForProjectRequest(_message.Message):
    __slots__ = ["project_id"]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class GetAllUserPermissionsForProjectResponse(_message.Message):
    __slots__ = ["users"]
    USERS_FIELD_NUMBER: _ClassVar[int]
    users: _containers.RepeatedCompositeFieldContainer[UserWithProjectPermissions]
    def __init__(self, users: _Optional[_Iterable[_Union[UserWithProjectPermissions, _Mapping]]] = ...) -> None: ...

class GetProjectRequest(_message.Message):
    __slots__ = ["project_id"]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class GetProjectResponse(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: _auth_pb2.ProjectOverview
    def __init__(self, project: _Optional[_Union[_auth_pb2.ProjectOverview, _Mapping]] = ...) -> None: ...

class GetProjectsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetProjectsResponse(_message.Message):
    __slots__ = ["projects"]
    PROJECTS_FIELD_NUMBER: _ClassVar[int]
    projects: _containers.RepeatedCompositeFieldContainer[_auth_pb2.ProjectOverview]
    def __init__(self, projects: _Optional[_Iterable[_Union[_auth_pb2.ProjectOverview, _Mapping]]] = ...) -> None: ...

class GetUserPermissionsForProjectRequest(_message.Message):
    __slots__ = ["project_id", "user_id"]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    user_id: str
    def __init__(self, project_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class GetUserPermissionsForProjectResponse(_message.Message):
    __slots__ = ["user_permission"]
    USER_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    user_permission: _auth_pb2.ProjectPermissionDisplayName
    def __init__(self, user_permission: _Optional[_Union[_auth_pb2.ProjectPermissionDisplayName, _Mapping]] = ...) -> None: ...

class RemoveUserFromProjectRequest(_message.Message):
    __slots__ = ["project_id", "user_id"]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    user_id: str
    def __init__(self, project_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class RemoveUserFromProjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateProjectRequest(_message.Message):
    __slots__ = ["description", "name", "project_id"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    description: str
    name: str
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class UpdateProjectResponse(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: _auth_pb2.ProjectOverview
    def __init__(self, project: _Optional[_Union[_auth_pb2.ProjectOverview, _Mapping]] = ...) -> None: ...

class UserWithProjectPermissions(_message.Message):
    __slots__ = ["user", "user_permissions"]
    USER_FIELD_NUMBER: _ClassVar[int]
    USER_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    user: _auth_pb2.User
    user_permissions: _auth_pb2.ProjectPermission
    def __init__(self, user: _Optional[_Union[_auth_pb2.User, _Mapping]] = ..., user_permissions: _Optional[_Union[_auth_pb2.ProjectPermission, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/object_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from aruna.api.storage.models.v1 import query_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2aruna/api/storage/services/v1/object_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a(aruna/api/storage/models/v1/models.proto\x1a\'aruna/api/storage/models/v1/query.proto\x1a\x1cgoogle/api/annotations.proto\"\x17\n\x03URL\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\"\xf0\x02\n\x0bStageObject\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12\x1f\n\x0b\x63ontent_len\x18\x04 \x01(\x03R\ncontentLen\x12;\n\x06source\x18\x05 \x01(\x0b\x32#.aruna.api.storage.models.v1.SourceR\x06source\x12\x44\n\tdataclass\x18\x06 \x01(\x0e\x32&.aruna.api.storage.models.v1.DataClassR\tdataclass\x12=\n\x06labels\x18\x07 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x08 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\x12\x19\n\x08sub_path\x18\t \x01(\tR\x07subPathJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"\xb9\x02\n\x1aInitializeNewObjectRequest\x12\x42\n\x06object\x18\x01 \x01(\x0b\x32*.aruna.api.storage.services.v1.StageObjectR\x06object\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x32\n\x15preferred_endpoint_id\x18\x04 \x01(\tR\x13preferredEndpointId\x12\x1c\n\tmultipart\x18\x05 \x01(\x08R\tmultipart\x12)\n\x10is_specification\x18\x06 \x01(\x08R\x0fisSpecification\x12\x35\n\x04hash\x18\x07 \x01(\x0b\x32!.aruna.api.storage.models.v1.HashR\x04hash\"|\n\x1bInitializeNewObjectResponse\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1b\n\tupload_id\x18\x02 \x01(\tR\x08uploadId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\"\xb3\x01\n\x13GetUploadURLRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1b\n\tupload_id\x18\x02 \x01(\tR\x08uploadId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\x12\x1c\n\tmultipart\x18\x04 \x01(\x08R\tmultipart\x12\x1f\n\x0bpart_number\x18\x05 \x01(\x05R\npartNumber\"L\n\x14GetUploadURLResponse\x12\x34\n\x03url\x18\x01 \x01(\x0b\x32\".aruna.api.storage.services.v1.URLR\x03url\"8\n\x0e\x43ompletedParts\x12\x12\n\x04\x65tag\x18\x01 \x01(\tR\x04\x65tag\x12\x12\n\x04part\x18\x02 \x01(\x03R\x04part\"Y\n\x15GetDownloadURLRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\"N\n\x16GetDownloadURLResponse\x12\x34\n\x03url\x18\x01 \x01(\x0b\x32\".aruna.api.storage.services.v1.URLR\x03url\"]\n\x1cGetDownloadLinksBatchRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x18\n\x07objects\x18\x02 \x03(\tR\x07objects\"W\n\x1dGetDownloadLinksBatchResponse\x12\x36\n\x04urls\x18\x01 \x03(\x0b\x32\".aruna.api.storage.services.v1.URLR\x04urls\"a\n CreateDownloadLinksStreamRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x18\n\x07objects\x18\x02 \x03(\tR\x07objects\"Y\n!CreateDownloadLinksStreamResponse\x12\x34\n\x03url\x18\x01 \x01(\x0b\x32\".aruna.api.storage.services.v1.URLR\x03url\"\xc8\x02\n\x1a\x46inishObjectStagingRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1b\n\tupload_id\x18\x02 \x01(\tR\x08uploadId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\x12\x35\n\x04hash\x18\x04 \x01(\x0b\x32!.aruna.api.storage.models.v1.HashR\x04hash\x12\x1b\n\tno_upload\x18\x05 \x01(\x08R\x08noUpload\x12V\n\x0f\x63ompleted_parts\x18\x06 \x03(\x0b\x32-.aruna.api.storage.services.v1.CompletedPartsR\x0e\x63ompletedParts\x12\x1f\n\x0b\x61uto_update\x18\x07 \x01(\x08R\nautoUpdate\"Z\n\x1b\x46inishObjectStagingResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\xf2\x02\n\x13UpdateObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x42\n\x06object\x18\x03 \x01(\x0b\x32*.aruna.api.storage.services.v1.StageObjectR\x06object\x12\x1a\n\x08reupload\x18\x04 \x01(\x08R\x08reupload\x12\x32\n\x15preferred_endpoint_id\x18\x05 \x01(\tR\x13preferredEndpointId\x12\x1d\n\nmulti_part\x18\x06 \x01(\x08R\tmultiPart\x12)\n\x10is_specification\x18\x07 \x01(\x08R\x0fisSpecification\x12\x35\n\x04hash\x18\t \x01(\x0b\x32!.aruna.api.storage.models.v1.HashR\x04hashJ\x04\x08\x08\x10\t\"w\n\x14UpdateObjectResponse\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1d\n\nstaging_id\x18\x02 \x01(\tR\tstagingId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\"\xec\x01\n\x1c\x43reateObjectReferenceRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x30\n\x14target_collection_id\x18\x03 \x01(\tR\x12targetCollectionId\x12\x1c\n\twriteable\x18\x04 \x01(\x08R\twriteable\x12\x1f\n\x0b\x61uto_update\x18\x05 \x01(\x08R\nautoUpdate\x12\x19\n\x08sub_path\x18\x06 \x01(\tR\x07subPath\"\x1f\n\x1d\x43reateObjectReferenceResponse\"\x88\x01\n\x12\x43loneObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x30\n\x14target_collection_id\x18\x03 \x01(\tR\x12targetCollectionId\"R\n\x13\x43loneObjectResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\x94\x01\n\x13\x44\x65leteObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12%\n\x0ewith_revisions\x18\x03 \x01(\x08R\rwithRevisions\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x16\n\x14\x44\x65leteObjectResponse\"\x97\x01\n\x14\x44\x65leteObjectsRequest\x12\x1d\n\nobject_ids\x18\x01 \x03(\tR\tobjectIds\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12%\n\x0ewith_revisions\x18\x03 \x01(\x08R\rwithRevisions\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x17\n\x15\x44\x65leteObjectsResponse\"t\n\rObjectWithURL\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\x12\x14\n\x05paths\x18\x03 \x03(\tR\x05paths\"s\n\x14GetObjectByIDRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12\x19\n\x08with_url\x18\x04 \x01(\x08R\x07withUrl\"]\n\x15GetObjectByIDResponse\x12\x44\n\x06object\x18\x01 \x01(\x0b\x32,.aruna.api.storage.services.v1.ObjectWithURLR\x06object\"\xf5\x01\n\x11GetObjectsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12K\n\x0cpage_request\x18\x02 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\x12S\n\x0flabel_id_filter\x18\x03 \x01(\x0b\x32+.aruna.api.storage.models.v1.LabelOrIDQueryR\rlabelIdFilter\x12\x19\n\x08with_url\x18\x04 \x01(\x08R\x07withUrl\"\\\n\x12GetObjectsResponse\x12\x46\n\x07objects\x18\x01 \x03(\x0b\x32,.aruna.api.storage.services.v1.ObjectWithURLR\x07objects\"\xc5\x01\n\x19GetObjectRevisionsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12K\n\x0cpage_request\x18\x03 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\x12\x19\n\x08with_url\x18\x04 \x01(\x08R\x07withUrl\"d\n\x1aGetObjectRevisionsResponse\x12\x46\n\x07objects\x18\x01 \x03(\x0b\x32,.aruna.api.storage.services.v1.ObjectWithURLR\x07objects\"}\n\x1eGetLatestObjectRevisionRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12\x19\n\x08with_url\x18\x03 \x01(\x08R\x07withUrl\"g\n\x1fGetLatestObjectRevisionResponse\x12\x44\n\x06object\x18\x01 \x01(\x0b\x32,.aruna.api.storage.services.v1.ObjectWithURLR\x06object\"]\n\x19GetObjectEndpointsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\"a\n\x1aGetObjectEndpointsResponse\x12\x43\n\tendpoints\x18\x01 \x03(\x0b\x32%.aruna.api.storage.models.v1.EndpointR\tendpoints\"\xa7\x01\n\x18\x41\x64\x64LabelsToObjectRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12I\n\rlabels_to_add\x18\x03 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x0blabelsToAdd\"X\n\x19\x41\x64\x64LabelsToObjectResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\x98\x01\n\x17SetHooksOfObjectRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12;\n\x05hooks\x18\x03 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\"W\n\x18SetHooksOfObjectResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\x7f\n\x14GetReferencesRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12%\n\x0ewith_revisions\x18\x03 \x01(\x08R\rwithRevisions\"\x9f\x01\n\x0fObjectReference\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\'\n\x0frevision_number\x18\x03 \x01(\x03R\x0erevisionNumber\x12!\n\x0cis_writeable\x18\x04 \x01(\x08R\x0bisWriteable\"g\n\x15GetReferencesResponse\x12N\n\nreferences\x18\x01 \x03(\x0b\x32..aruna.api.storage.services.v1.ObjectReferenceR\nreferences\":\n\x04Path\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x1e\n\nvisibility\x18\x02 \x01(\x08R\nvisibility\"\x83\x01\n\x14GetObjectPathRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12)\n\x10include_inactive\x18\x03 \x01(\x08R\x0fincludeInactive\"_\n\x15GetObjectPathResponse\x12\x46\n\x0cobject_paths\x18\x01 \x03(\x0b\x32#.aruna.api.storage.services.v1.PathR\x0bobjectPaths\"g\n\x15GetObjectPathsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12)\n\x10include_inactive\x18\x02 \x01(\x08R\x0fincludeInactive\"`\n\x16GetObjectPathsResponse\x12\x46\n\x0cobject_paths\x18\x01 \x03(\x0b\x32#.aruna.api.storage.services.v1.PathR\x0bobjectPaths\"v\n\x17\x43reateObjectPathRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12\x19\n\x08sub_path\x18\x03 \x01(\tR\x07subPath\"S\n\x18\x43reateObjectPathResponse\x12\x37\n\x04path\x18\x01 \x01(\x0b\x32#.aruna.api.storage.services.v1.PathR\x04path\"y\n\x1eSetObjectPathVisibilityRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x1e\n\nvisibility\x18\x03 \x01(\x08R\nvisibility\"Z\n\x1fSetObjectPathVisibilityResponse\x12\x37\n\x04path\x18\x01 \x01(\x0b\x32#.aruna.api.storage.services.v1.PathR\x04path\"T\n\x17GetObjectsByPathRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12%\n\x0ewith_revisions\x18\x02 \x01(\x08R\rwithRevisions\":\n$GetProjectCollectionIdsByPathRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\"k\n%GetProjectCollectionIdsByPathResponse\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\"W\n\x18GetObjectsByPathResponse\x12;\n\x06object\x18\x03 \x03(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object2\x99\'\n\rObjectService\x12\xbe\x01\n\x13InitializeNewObject\x12\x39.aruna.api.storage.services.v1.InitializeNewObjectRequest\x1a:.aruna.api.storage.services.v1.InitializeNewObjectResponse\"0\x82\xd3\xe4\x93\x02*:\x01*\"%/v1/collection/{collection_id}/object\x12\xcd\x01\n\x0cGetUploadURL\x12\x32.aruna.api.storage.services.v1.GetUploadURLRequest\x1a\x33.aruna.api.storage.services.v1.GetUploadURLResponse\"T\x82\xd3\xe4\x93\x02N\x12L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/upload\x12\xc1\x01\n\x0eGetDownloadURL\x12\x34.aruna.api.storage.services.v1.GetDownloadURLRequest\x1a\x35.aruna.api.storage.services.v1.GetDownloadURLResponse\"B\x82\xd3\xe4\x93\x02<\x12:/v1/collection/{collection_id}/object/{object_id}/download\x12\xc8\x01\n\x15GetDownloadLinksBatch\x12;.aruna.api.storage.services.v1.GetDownloadLinksBatchRequest\x1a<.aruna.api.storage.services.v1.GetDownloadLinksBatchResponse\"4\x82\xd3\xe4\x93\x02.\x12,/v1/collection/{collection_id}/objects/batch\x12\xda\x01\n\x19\x43reateDownloadLinksStream\x12?.aruna.api.storage.services.v1.CreateDownloadLinksStreamRequest\x1a@.aruna.api.storage.services.v1.CreateDownloadLinksStreamResponse\"8\x82\xd3\xe4\x93\x02\x32:\x01*\"-/v1/collection/{collection_id}/objects/stream0\x01\x12\xe5\x01\n\x13\x46inishObjectStaging\x12\x39.aruna.api.storage.services.v1.FinishObjectStagingRequest\x1a:.aruna.api.storage.services.v1.FinishObjectStagingResponse\"W\x82\xd3\xe4\x93\x02Q:\x01*2L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/finish\x12\xbc\x01\n\x0cUpdateObject\x12\x32.aruna.api.storage.services.v1.UpdateObjectRequest\x1a\x33.aruna.api.storage.services.v1.UpdateObjectResponse\"C\x82\xd3\xe4\x93\x02=:\x01*\"8/v1/collection/{collection_id}/object/{object_id}/update\x12\xf1\x01\n\x15\x43reateObjectReference\x12;.aruna.api.storage.services.v1.CreateObjectReferenceRequest\x1a<.aruna.api.storage.services.v1.CreateObjectReferenceResponse\"]\x82\xd3\xe4\x93\x02W:\x01*\"R/v1/collection/{collection_id}/object/{object_id}/reference/{target_collection_id}\x12\xb8\x01\n\x0b\x43loneObject\x12\x31.aruna.api.storage.services.v1.CloneObjectRequest\x1a\x32.aruna.api.storage.services.v1.CloneObjectResponse\"B\x82\xd3\xe4\x93\x02<:\x01*\"7/v1/collection/{collection_id}/object/{object_id}/clone\x12\xb5\x01\n\x0c\x44\x65leteObject\x12\x32.aruna.api.storage.services.v1.DeleteObjectRequest\x1a\x33.aruna.api.storage.services.v1.DeleteObjectResponse\"<\x82\xd3\xe4\x93\x02\x36:\x01**1/v1/collection/{collection_id}/object/{object_id}\x12\xad\x01\n\rDeleteObjects\x12\x33.aruna.api.storage.services.v1.DeleteObjectsRequest\x1a\x34.aruna.api.storage.services.v1.DeleteObjectsResponse\"1\x82\xd3\xe4\x93\x02+:\x01**&/v1/collection/{collection_id}/objects\x12\xb5\x01\n\rGetObjectByID\x12\x33.aruna.api.storage.services.v1.GetObjectByIDRequest\x1a\x34.aruna.api.storage.services.v1.GetObjectByIDResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/collection/{collection_id}/object/{object_id}\x12\xa1\x01\n\nGetObjects\x12\x30.aruna.api.storage.services.v1.GetObjectsRequest\x1a\x31.aruna.api.storage.services.v1.GetObjectsResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/collection/{collection_id}/objects\x12\xce\x01\n\x12GetObjectRevisions\x12\x38.aruna.api.storage.services.v1.GetObjectRevisionsRequest\x1a\x39.aruna.api.storage.services.v1.GetObjectRevisionsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/v1/collection/{collection_id}/object/{object_id}/revisions\x12\xda\x01\n\x17GetLatestObjectRevision\x12=.aruna.api.storage.services.v1.GetLatestObjectRevisionRequest\x1a>.aruna.api.storage.services.v1.GetLatestObjectRevisionResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/v1/collection/{collection_id}/object/{object_id}/latest\x12\xce\x01\n\x12GetObjectEndpoints\x12\x38.aruna.api.storage.services.v1.GetObjectEndpointsRequest\x1a\x39.aruna.api.storage.services.v1.GetObjectEndpointsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/v1/collection/{collection_id}/object/{object_id}/endpoints\x12\xcf\x01\n\x11\x41\x64\x64LabelsToObject\x12\x37.aruna.api.storage.services.v1.AddLabelsToObjectRequest\x1a\x38.aruna.api.storage.services.v1.AddLabelsToObjectResponse\"G\x82\xd3\xe4\x93\x02\x41:\x01*2</v1/collection/{collection_id}/object/{object_id}/add_labels\x12\xcb\x01\n\x10SetHooksOfObject\x12\x36.aruna.api.storage.services.v1.SetHooksOfObjectRequest\x1a\x37.aruna.api.storage.services.v1.SetHooksOfObjectResponse\"F\x82\xd3\xe4\x93\x02@:\x01*2;/v1/collection/{collection_id}/object/{object_id}/set_hooks\x12\xc0\x01\n\rGetReferences\x12\x33.aruna.api.storage.services.v1.GetReferencesRequest\x1a\x34.aruna.api.storage.services.v1.GetReferencesResponse\"D\x82\xd3\xe4\x93\x02>\x12</v1/collection/{collection_id}/object/{object_id}/references\x12\xba\x01\n\rGetObjectPath\x12\x33.aruna.api.storage.services.v1.GetObjectPathRequest\x1a\x34.aruna.api.storage.services.v1.GetObjectPathResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/v1/collection/{collection_id}/object/{object_id}/path\x12\xab\x01\n\x0eGetObjectPaths\x12\x34.aruna.api.storage.services.v1.GetObjectPathsRequest\x1a\x35.aruna.api.storage.services.v1.GetObjectPathsResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/collection/{collection_id}/paths\x12\xc6\x01\n\x10\x43reateObjectPath\x12\x36.aruna.api.storage.services.v1.CreateObjectPathRequest\x1a\x37.aruna.api.storage.services.v1.CreateObjectPathResponse\"A\x82\xd3\xe4\x93\x02;:\x01*\"6/v1/collection/{collection_id}/object/{object_id}/path\x12\xdd\x01\n\x17SetObjectPathVisibility\x12=.aruna.api.storage.services.v1.SetObjectPathVisibilityRequest\x1a>.aruna.api.storage.services.v1.SetObjectPathVisibilityResponse\"C\x82\xd3\xe4\x93\x02=:\x01*28/v1/collection/{collection_id}/path/{path=**}/visibility\x12\xa6\x01\n\x10GetObjectsByPath\x12\x36.aruna.api.storage.services.v1.GetObjectsByPathRequest\x1a\x37.aruna.api.storage.services.v1.GetObjectsByPathResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/path/object/{path=**}\x12\xd1\x01\n\x1dGetProjectCollectionIdsByPath\x12\x43.aruna.api.storage.services.v1.GetProjectCollectionIdsByPathRequest\x1a\x44.aruna.api.storage.services.v1.GetProjectCollectionIdsByPathResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/path/collection/{path=**}B\x8f\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\rObjectServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.object_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\rObjectServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _OBJECTSERVICE.methods_by_name['InitializeNewObject']._options = None
  _OBJECTSERVICE.methods_by_name['InitializeNewObject']._serialized_options = b'\202\323\344\223\002*:\001*\"%/v1/collection/{collection_id}/object'
  _OBJECTSERVICE.methods_by_name['GetUploadURL']._options = None
  _OBJECTSERVICE.methods_by_name['GetUploadURL']._serialized_options = b'\202\323\344\223\002N\022L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/upload'
  _OBJECTSERVICE.methods_by_name['GetDownloadURL']._options = None
  _OBJECTSERVICE.methods_by_name['GetDownloadURL']._serialized_options = b'\202\323\344\223\002<\022:/v1/collection/{collection_id}/object/{object_id}/download'
  _OBJECTSERVICE.methods_by_name['GetDownloadLinksBatch']._options = None
  _OBJECTSERVICE.methods_by_name['GetDownloadLinksBatch']._serialized_options = b'\202\323\344\223\002.\022,/v1/collection/{collection_id}/objects/batch'
  _OBJECTSERVICE.methods_by_name['CreateDownloadLinksStream']._options = None
  _OBJECTSERVICE.methods_by_name['CreateDownloadLinksStream']._serialized_options = b'\202\323\344\223\0022:\001*\"-/v1/collection/{collection_id}/objects/stream'
  _OBJECTSERVICE.methods_by_name['FinishObjectStaging']._options = None
  _OBJECTSERVICE.methods_by_name['FinishObjectStaging']._serialized_options = b'\202\323\344\223\002Q:\001*2L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/finish'
  _OBJECTSERVICE.methods_by_name['UpdateObject']._options = None
  _OBJECTSERVICE.methods_by_name['UpdateObject']._serialized_options = b'\202\323\344\223\002=:\001*\"8/v1/collection/{collection_id}/object/{object_id}/update'
  _OBJECTSERVICE.methods_by_name['CreateObjectReference']._options = None
  _OBJECTSERVICE.methods_by_name['CreateObjectReference']._serialized_options = b'\202\323\344\223\002W:\001*\"R/v1/collection/{collection_id}/object/{object_id}/reference/{target_collection_id}'
  _OBJECTSERVICE.methods_by_name['CloneObject']._options = None
  _OBJECTSERVICE.methods_by_name['CloneObject']._serialized_options = b'\202\323\344\223\002<:\001*\"7/v1/collection/{collection_id}/object/{object_id}/clone'
  _OBJECTSERVICE.methods_by_name['DeleteObject']._options = None
  _OBJECTSERVICE.methods_by_name['DeleteObject']._serialized_options = b'\202\323\344\223\0026:\001**1/v1/collection/{collection_id}/object/{object_id}'
  _OBJECTSERVICE.methods_by_name['DeleteObjects']._options = None
  _OBJECTSERVICE.methods_by_name['DeleteObjects']._serialized_options = b'\202\323\344\223\002+:\001**&/v1/collection/{collection_id}/objects'
  _OBJECTSERVICE.methods_by_name['GetObjectByID']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectByID']._serialized_options = b'\202\323\344\223\0023\0221/v1/collection/{collection_id}/object/{object_id}'
  _OBJECTSERVICE.methods_by_name['GetObjects']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjects']._serialized_options = b'\202\323\344\223\002(\022&/v1/collection/{collection_id}/objects'
  _OBJECTSERVICE.methods_by_name['GetObjectRevisions']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectRevisions']._serialized_options = b'\202\323\344\223\002=\022;/v1/collection/{collection_id}/object/{object_id}/revisions'
  _OBJECTSERVICE.methods_by_name['GetLatestObjectRevision']._options = None
  _OBJECTSERVICE.methods_by_name['GetLatestObjectRevision']._serialized_options = b'\202\323\344\223\002:\0228/v1/collection/{collection_id}/object/{object_id}/latest'
  _OBJECTSERVICE.methods_by_name['GetObjectEndpoints']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectEndpoints']._serialized_options = b'\202\323\344\223\002=\022;/v1/collection/{collection_id}/object/{object_id}/endpoints'
  _OBJECTSERVICE.methods_by_name['AddLabelsToObject']._options = None
  _OBJECTSERVICE.methods_by_name['AddLabelsToObject']._serialized_options = b'\202\323\344\223\002A:\001*2</v1/collection/{collection_id}/object/{object_id}/add_labels'
  _OBJECTSERVICE.methods_by_name['SetHooksOfObject']._options = None
  _OBJECTSERVICE.methods_by_name['SetHooksOfObject']._serialized_options = b'\202\323\344\223\002@:\001*2;/v1/collection/{collection_id}/object/{object_id}/set_hooks'
  _OBJECTSERVICE.methods_by_name['GetReferences']._options = None
  _OBJECTSERVICE.methods_by_name['GetReferences']._serialized_options = b'\202\323\344\223\002>\022</v1/collection/{collection_id}/object/{object_id}/references'
  _OBJECTSERVICE.methods_by_name['GetObjectPath']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectPath']._serialized_options = b'\202\323\344\223\0028\0226/v1/collection/{collection_id}/object/{object_id}/path'
  _OBJECTSERVICE.methods_by_name['GetObjectPaths']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectPaths']._serialized_options = b'\202\323\344\223\002&\022$/v1/collection/{collection_id}/paths'
  _OBJECTSERVICE.methods_by_name['CreateObjectPath']._options = None
  _OBJECTSERVICE.methods_by_name['CreateObjectPath']._serialized_options = b'\202\323\344\223\002;:\001*\"6/v1/collection/{collection_id}/object/{object_id}/path'
  _OBJECTSERVICE.methods_by_name['SetObjectPathVisibility']._options = None
  _OBJECTSERVICE.methods_by_name['SetObjectPathVisibility']._serialized_options = b'\202\323\344\223\002=:\001*28/v1/collection/{collection_id}/path/{path=**}/visibility'
  _OBJECTSERVICE.methods_by_name['GetObjectsByPath']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectsByPath']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/path/object/{path=**}'
  _OBJECTSERVICE.methods_by_name['GetProjectCollectionIdsByPath']._options = None
  _OBJECTSERVICE.methods_by_name['GetProjectCollectionIdsByPath']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/path/collection/{path=**}'
  _URL._serialized_start=198
  _URL._serialized_end=221
  _STAGEOBJECT._serialized_start=224
  _STAGEOBJECT._serialized_end=592
  _INITIALIZENEWOBJECTREQUEST._serialized_start=595
  _INITIALIZENEWOBJECTREQUEST._serialized_end=908
  _INITIALIZENEWOBJECTRESPONSE._serialized_start=910
  _INITIALIZENEWOBJECTRESPONSE._serialized_end=1034
  _GETUPLOADURLREQUEST._serialized_start=1037
  _GETUPLOADURLREQUEST._serialized_end=1216
  _GETUPLOADURLRESPONSE._serialized_start=1218
  _GETUPLOADURLRESPONSE._serialized_end=1294
  _COMPLETEDPARTS._serialized_start=1296
  _COMPLETEDPARTS._serialized_end=1352
  _GETDOWNLOADURLREQUEST._serialized_start=1354
  _GETDOWNLOADURLREQUEST._serialized_end=1443
  _GETDOWNLOADURLRESPONSE._serialized_start=1445
  _GETDOWNLOADURLRESPONSE._serialized_end=1523
  _GETDOWNLOADLINKSBATCHREQUEST._serialized_start=1525
  _GETDOWNLOADLINKSBATCHREQUEST._serialized_end=1618
  _GETDOWNLOADLINKSBATCHRESPONSE._serialized_start=1620
  _GETDOWNLOADLINKSBATCHRESPONSE._serialized_end=1707
  _CREATEDOWNLOADLINKSSTREAMREQUEST._serialized_start=1709
  _CREATEDOWNLOADLINKSSTREAMREQUEST._serialized_end=1806
  _CREATEDOWNLOADLINKSSTREAMRESPONSE._serialized_start=1808
  _CREATEDOWNLOADLINKSSTREAMRESPONSE._serialized_end=1897
  _FINISHOBJECTSTAGINGREQUEST._serialized_start=1900
  _FINISHOBJECTSTAGINGREQUEST._serialized_end=2228
  _FINISHOBJECTSTAGINGRESPONSE._serialized_start=2230
  _FINISHOBJECTSTAGINGRESPONSE._serialized_end=2320
  _UPDATEOBJECTREQUEST._serialized_start=2323
  _UPDATEOBJECTREQUEST._serialized_end=2693
  _UPDATEOBJECTRESPONSE._serialized_start=2695
  _UPDATEOBJECTRESPONSE._serialized_end=2814
  _CREATEOBJECTREFERENCEREQUEST._serialized_start=2817
  _CREATEOBJECTREFERENCEREQUEST._serialized_end=3053
  _CREATEOBJECTREFERENCERESPONSE._serialized_start=3055
  _CREATEOBJECTREFERENCERESPONSE._serialized_end=3086
  _CLONEOBJECTREQUEST._serialized_start=3089
  _CLONEOBJECTREQUEST._serialized_end=3225
  _CLONEOBJECTRESPONSE._serialized_start=3227
  _CLONEOBJECTRESPONSE._serialized_end=3309
  _DELETEOBJECTREQUEST._serialized_start=3312
  _DELETEOBJECTREQUEST._serialized_end=3460
  _DELETEOBJECTRESPONSE._serialized_start=3462
  _DELETEOBJECTRESPONSE._serialized_end=3484
  _DELETEOBJECTSREQUEST._serialized_start=3487
  _DELETEOBJECTSREQUEST._serialized_end=3638
  _DELETEOBJECTSRESPONSE._serialized_start=3640
  _DELETEOBJECTSRESPONSE._serialized_end=3663
  _OBJECTWITHURL._serialized_start=3665
  _OBJECTWITHURL._serialized_end=3781
  _GETOBJECTBYIDREQUEST._serialized_start=3783
  _GETOBJECTBYIDREQUEST._serialized_end=3898
  _GETOBJECTBYIDRESPONSE._serialized_start=3900
  _GETOBJECTBYIDRESPONSE._serialized_end=3993
  _GETOBJECTSREQUEST._serialized_start=3996
  _GETOBJECTSREQUEST._serialized_end=4241
  _GETOBJECTSRESPONSE._serialized_start=4243
  _GETOBJECTSRESPONSE._serialized_end=4335
  _GETOBJECTREVISIONSREQUEST._serialized_start=4338
  _GETOBJECTREVISIONSREQUEST._serialized_end=4535
  _GETOBJECTREVISIONSRESPONSE._serialized_start=4537
  _GETOBJECTREVISIONSRESPONSE._serialized_end=4637
  _GETLATESTOBJECTREVISIONREQUEST._serialized_start=4639
  _GETLATESTOBJECTREVISIONREQUEST._serialized_end=4764
  _GETLATESTOBJECTREVISIONRESPONSE._serialized_start=4766
  _GETLATESTOBJECTREVISIONRESPONSE._serialized_end=4869
  _GETOBJECTENDPOINTSREQUEST._serialized_start=4871
  _GETOBJECTENDPOINTSREQUEST._serialized_end=4964
  _GETOBJECTENDPOINTSRESPONSE._serialized_start=4966
  _GETOBJECTENDPOINTSRESPONSE._serialized_end=5063
  _ADDLABELSTOOBJECTREQUEST._serialized_start=5066
  _ADDLABELSTOOBJECTREQUEST._serialized_end=5233
  _ADDLABELSTOOBJECTRESPONSE._serialized_start=5235
  _ADDLABELSTOOBJECTRESPONSE._serialized_end=5323
  _SETHOOKSOFOBJECTREQUEST._serialized_start=5326
  _SETHOOKSOFOBJECTREQUEST._serialized_end=5478
  _SETHOOKSOFOBJECTRESPONSE._serialized_start=5480
  _SETHOOKSOFOBJECTRESPONSE._serialized_end=5567
  _GETREFERENCESREQUEST._serialized_start=5569
  _GETREFERENCESREQUEST._serialized_end=5696
  _OBJECTREFERENCE._serialized_start=5699
  _OBJECTREFERENCE._serialized_end=5858
  _GETREFERENCESRESPONSE._serialized_start=5860
  _GETREFERENCESRESPONSE._serialized_end=5963
  _PATH._serialized_start=5965
  _PATH._serialized_end=6023
  _GETOBJECTPATHREQUEST._serialized_start=6026
  _GETOBJECTPATHREQUEST._serialized_end=6157
  _GETOBJECTPATHRESPONSE._serialized_start=6159
  _GETOBJECTPATHRESPONSE._serialized_end=6254
  _GETOBJECTPATHSREQUEST._serialized_start=6256
  _GETOBJECTPATHSREQUEST._serialized_end=6359
  _GETOBJECTPATHSRESPONSE._serialized_start=6361
  _GETOBJECTPATHSRESPONSE._serialized_end=6457
  _CREATEOBJECTPATHREQUEST._serialized_start=6459
  _CREATEOBJECTPATHREQUEST._serialized_end=6577
  _CREATEOBJECTPATHRESPONSE._serialized_start=6579
  _CREATEOBJECTPATHRESPONSE._serialized_end=6662
  _SETOBJECTPATHVISIBILITYREQUEST._serialized_start=6664
  _SETOBJECTPATHVISIBILITYREQUEST._serialized_end=6785
  _SETOBJECTPATHVISIBILITYRESPONSE._serialized_start=6787
  _SETOBJECTPATHVISIBILITYRESPONSE._serialized_end=6877
  _GETOBJECTSBYPATHREQUEST._serialized_start=6879
  _GETOBJECTSBYPATHREQUEST._serialized_end=6963
  _GETPROJECTCOLLECTIONIDSBYPATHREQUEST._serialized_start=6965
  _GETPROJECTCOLLECTIONIDSBYPATHREQUEST._serialized_end=7023
  _GETPROJECTCOLLECTIONIDSBYPATHRESPONSE._serialized_start=7025
  _GETPROJECTCOLLECTIONIDSBYPATHRESPONSE._serialized_end=7132
  _GETOBJECTSBYPATHRESPONSE._serialized_start=7134
  _GETOBJECTSBYPATHRESPONSE._serialized_end=7221
  _OBJECTSERVICE._serialized_start=7224
  _OBJECTSERVICE._serialized_end=12241
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.storage.services.v1 import objectgroup_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2


class ObjectGroupServiceStub(object):
    """ObjectService

    Contains all methods that get/create or update Objects and associated resource
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateObjectGroup = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectGroupService/CreateObjectGroup',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.CreateObjectGroupRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.CreateObjectGroupResponse.FromString,
                )
        self.UpdateObjectGroup = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectGroupService/UpdateObjectGroup',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.UpdateObjectGroupRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.UpdateObjectGroupResponse.FromString,
                )
        self.GetObjectGroupById = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectGroupService/GetObjectGroupById',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupByIdRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupByIdResponse.FromString,
                )
        self.GetObjectGroupsFromObject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectGroupService/GetObjectGroupsFromObject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsFromObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsFromObjectResponse.FromString,
                )
        self.GetObjectGroups = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectGroupService/GetObjectGroups',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsResponse.FromString,
                )
        self.GetObjectGroupHistory = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectGroupService/GetObjectGroupHistory',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupHistoryRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupHistoryResponse.FromString,
                )
        self.GetObjectGroupObjects = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectGroupService/GetObjectGroupObjects',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupObjectsRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupObjectsResponse.FromString,
                )
        self.DeleteObjectGroup = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectGroupService/DeleteObjectGroup',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.DeleteObjectGroupRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.DeleteObjectGroupResponse.FromString,
                )
        self.AddLabelsToObjectGroup = channel.unary_unary(
                '/aruna.api.storage.services.v1.ObjectGroupService/AddLabelsToObjectGroup',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.AddLabelsToObjectGroupRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.AddLabelsToObjectGroupResponse.FromString,
                )


class ObjectGroupServiceServicer(object):
    """ObjectService

    Contains all methods that get/create or update Objects and associated resource
    """

    def CreateObjectGroup(self, request, context):
        """CreateObjectGroup

        Status: STABLE

        This creates a new ObjectGroup in the collection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateObjectGroup(self, request, context):
        """UpdateObjectGroup

        Status: STABLE

        This creates an updated ObjectGroup
        ObjectGroups are immutable
        Updating an ObjectGroup will create a new Revision of the ObjectGroup
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectGroupById(self, request, context):
        """GetObjectGroupById

        Status: STABLE

        This gets a specific ObjectGroup by ID
        By default the latest revision is always returned, older revisions need to
        be specified separately
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectGroupsFromObject(self, request, context):
        """GetObjectGroupsFromObject

        Status: STABLE

        This gets all ObjectGroups associated to a specific
        Object Objects can be part of multiple ObjectGroups at once
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectGroups(self, request, context):
        """GetObjectGroups

        Status: STABLE

        This is a request that returns a (paginated) list of
        ObjectGroups that contain a specific set of labels.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectGroupHistory(self, request, context):
        """GetObjectGroupHistory

        Status: BETA

        This requests a full history with all objectgroups
        that are part of this objectgroups history
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectGroupObjects(self, request, context):
        """GetObjectGroupObjects

        Status: STABLE

        Requests a list of paginated objects associated with this
        specific objectgroup
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteObjectGroup(self, request, context):
        """DeleteObjectGroup

        Status: STABLE

        This is a request that deletes a specified ObjectGroup
        This does not delete the associated Objects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddLabelsToObjectGroup(self, request, context):
        """AddLabelsToObjectGroup 

        Status: STABLE

        This is a specific request to add new label(s)
        to an existing object_group, in contrast to UpdateObjectGroup
        this will not create a new revision for the specific object_group
        Instead it will directly add the specified label(s) to the object_group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ObjectGroupServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateObjectGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateObjectGroup,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.CreateObjectGroupRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.CreateObjectGroupResponse.SerializeToString,
            ),
            'UpdateObjectGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateObjectGroup,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.UpdateObjectGroupRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.UpdateObjectGroupResponse.SerializeToString,
            ),
            'GetObjectGroupById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectGroupById,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupByIdRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupByIdResponse.SerializeToString,
            ),
            'GetObjectGroupsFromObject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectGroupsFromObject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsFromObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsFromObjectResponse.SerializeToString,
            ),
            'GetObjectGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectGroups,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsResponse.SerializeToString,
            ),
            'GetObjectGroupHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectGroupHistory,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupHistoryRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupHistoryResponse.SerializeToString,
            ),
            'GetObjectGroupObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectGroupObjects,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupObjectsRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupObjectsResponse.SerializeToString,
            ),
            'DeleteObjectGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteObjectGroup,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.DeleteObjectGroupRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.DeleteObjectGroupResponse.SerializeToString,
            ),
            'AddLabelsToObjectGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.AddLabelsToObjectGroup,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.AddLabelsToObjectGroupRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.AddLabelsToObjectGroupResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.storage.services.v1.ObjectGroupService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ObjectGroupService(object):
    """ObjectService

    Contains all methods that get/create or update Objects and associated resource
    """

    @staticmethod
    def CreateObjectGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectGroupService/CreateObjectGroup',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.CreateObjectGroupRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.CreateObjectGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateObjectGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectGroupService/UpdateObjectGroup',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.UpdateObjectGroupRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.UpdateObjectGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectGroupById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectGroupService/GetObjectGroupById',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupByIdRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectGroupsFromObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectGroupService/GetObjectGroupsFromObject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsFromObjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsFromObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectGroupService/GetObjectGroups',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectGroupHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectGroupService/GetObjectGroupHistory',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupHistoryRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectGroupObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectGroupService/GetObjectGroupObjects',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupObjectsRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.GetObjectGroupObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteObjectGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectGroupService/DeleteObjectGroup',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.DeleteObjectGroupRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.DeleteObjectGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddLabelsToObjectGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ObjectGroupService/AddLabelsToObjectGroup',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.AddLabelsToObjectGroupRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_objectgroup__service__pb2.AddLabelsToObjectGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
